@@ -1,6 +1,4 @@
 from pyvim.current import current
-from pyvim.environment import env
-from pyvim.environment import environment
 from pyvim.function import Function
 from pyvim.highlighting import highlight_groups
 from pyvim.job import Job
@@ -10,8 +8,6 @@ from pyvim.register import Register
 
 __all__ = [
     "current",
-    "env",
-    "environment",
     "echo",
     "highlight_groups",
     "Function",
